@@ -1,7 +1,7 @@
 // -*- mode: c++; c-file-style: "linux"; c-basic-offset: 2; indent-tabs-mode: nil -*-
 //
 //  Copyright (C) 2004-2015 Andrej Vodopivec <andrej.vodopivec@gmail.com>
-//            (C) 2014-2015 Gunter Königsmann <wxMaxima@physikbuch.de>
+//            (C) 2014-2016 Gunter Königsmann <wxMaxima@physikbuch.de>
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -148,6 +148,12 @@ wxString AtCell::ToTeX()
   return s;
 }
 
+wxString AtCell::ToMathML()
+{
+  return wxT("<msub>") + m_baseCell->ListToMathML() + 
+    m_indexCell->ListToMathML() + wxT("</msub>\n");
+}
+
 wxString AtCell::ToXML()
 {
   return wxT("<at><r>") + m_baseCell->ListToXML() + wxT("</r><r>") +
