@@ -80,6 +80,7 @@ bool AutoComplete::LoadSymbols(wxString file)
   m_wordList[command].Add(wxT("wxdraw"));
   m_wordList[command].Add(wxT("wxdraw2d"));
   m_wordList[command].Add(wxT("wxdraw3d"));
+  m_wordList[command].Add(wxT("wxfilename"));
   m_wordList[command].Add(wxT("wxhistogram"));
   m_wordList[command].Add(wxT("wxscatterplot"));
   m_wordList[command].Add(wxT("wxbarsplot"));
@@ -87,10 +88,15 @@ bool AutoComplete::LoadSymbols(wxString file)
   m_wordList[command].Add(wxT("wxboxplot"));
   m_wordList[command].Add(wxT("wxplot_size"));
   m_wordList[command].Add(wxT("wxdraw_list"));
-  m_wordList[command].Add(wxT("table_form"));
   m_wordList[command].Add(wxT("wxbuild_info"));
+  m_wordList[command].Add(wxT("show_image"));
+  m_wordList[tmplte ].Add(wxT("show_image(<imagename>)"));
+  m_wordList[command].Add(wxT("table_form"));
   m_wordList[tmplte].Add(wxT("table_form(<data>)"));
   m_wordList[tmplte].Add(wxT("table_form(<data>,<[options]>)"));
+  m_wordList[command].Add(wxT("wxsubscripts"));
+  m_wordList[command].Add(wxT("wxdeclare_subscripted"));
+  m_wordList[tmplte].Add(wxT("wxdeclare_subscripted(<name>,<[false]>)"));
 
   /// Load private symbol list (do something different on Windows).
   wxString privateList;
