@@ -1,7 +1,7 @@
 // -*- mode: c++; c-file-style: "linux"; c-basic-offset: 2; indent-tabs-mode: nil -*-
 //
 //  Copyright (C) 2004-2015 Andrej Vodopivec <andrej.vodopivec@gmail.com>
-//            (C) 2014-2015 Gunter Königsmann <wxMaxima@physikbuch.de>
+//            (C) 2014-2016 Gunter Königsmann <wxMaxima@physikbuch.de>
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -20,6 +20,7 @@
 //
 
 #include "DiffCell.h"
+#include "wx/config.h"
 
 DiffCell::DiffCell() : MathCell()
 {
@@ -75,7 +76,7 @@ void DiffCell::SetDiff(MathCell *diff)
     delete m_diffCell;
   m_diffCell = diff;
 
-  m_diffCell->m_SuppressMultiplicationDot=true;
+  m_diffCell->m_SuppressMultiplicationDot = true;
 }
 
 void DiffCell::SetBase(MathCell *base)
@@ -133,14 +134,36 @@ wxString DiffCell::ToString()
 
 wxString DiffCell::ToTeX()
 {
-  wxString s = m_diffCell->ListToTeX() + m_baseCell->ListToTeX();
+  wxString diff=m_diffCell->ListToTeX();
+  wxString function=m_baseCell->ListToTeX();
+
+  bool usePartialForDiff = false;
+  wxConfig::Get()->Read(wxT("usePartialForDiff"), &usePartialForDiff);
+  if(usePartialForDiff)
+    diff.Replace(wxT("\\frac{d}{d"),wxT("\\frac{\\partial}{\\partial"));
+
+  wxString s = diff + function;
   return s;
 }
 
+wxString DiffCell::ToMathML()
+{
+  wxString retval;
+
+  retval = wxT("<mrow>")+m_diffCell->ListToMathML();
+  if(m_baseCell) 
+    retval += m_baseCell->ListToMathML();
+  retval += wxT("</mrow>\n");
+  // retval = wxT("<apply><diff/><ci>") + m_diffCell->ListToMathML() + wxT("</ci>");
+  // if(m_baseCell)
+  //   retval += wxT("<ci>") + m_baseCell->ListToMathML() + wxT("</ci>") ;
+  // retval += wxT("</apply>");
+  return retval;
+}
+
 wxString DiffCell::ToXML()
 {
-  return _T("<d>") + m_baseCell->ListToXML() +
-    m_diffCell->ListToXML() + _T("</d>");
+  return _T("<d>") + m_diffCell->ListToXML() + m_baseCell->ListToXML() + _T("</d>");
 }
 
 void DiffCell::SelectInner(wxRect& rect, MathCell** first, MathCell** last)
