@@ -46,6 +46,7 @@ void EvaluationQueue::Clear()
   while(!Empty())
     RemoveFirst();
   m_size = 0;
+  m_tokens.Clear();
   m_workingGroupChanged = false;
 }
 
@@ -131,24 +132,36 @@ void EvaluationQueue::AddTokens(wxString commandString)
 {
   size_t index = 0;
 
+
   wxString token;
 
   while(index < commandString.Length())
   {
     wxChar ch = commandString[index];
 
-    // Process strings
+    // Add strings as a whole
     if(ch == wxT('\"'))
     {
       token += ch;
       index++;
-      while((index < commandString.Length()) && (commandString[index] != wxT('\"')))
+      while((index < commandString.Length()) && ((ch = commandString[index]) != wxT('\"')))
       {
+        if(commandString[index]==wxT('\\'))
+        {
+          token += commandString[index];
+          index++;
+        }
         token += commandString[index];
         index++;
       }
+      if (index < commandString.Length())
+      {
+        token += commandString[index];
+        index++;  
+      }
+      continue;
     }
-
+    
     // :lisp -commands should be added as a whole
     if(ch == wxT(':'))
     {
@@ -164,9 +177,17 @@ void EvaluationQueue::AddTokens(wxString commandString)
     // Handle escaped chars
     if(ch == wxT('\\'))
     {
+      if((index + 1 < commandString.Length())&&(commandString[index+1]==wxT('\n')))
+      {
+        index+=2;
+        continue;
+      }
+      
       token += ch;
       index++;
-      ch = commandString[index];
+      if(index < commandString.Length())
+        token +=  commandString[index++];
+      continue;
     }
       
     // Remove comments
@@ -198,17 +219,22 @@ void EvaluationQueue::AddTokens(wxString commandString)
       )
     {
       // trim() the token to allow MathCtrl::TryEvaluateNextInQueue()
-      // to detect if the token is empty.      
-      token.Trim(true).Trim(false);
-      m_tokens.Add(token);
+      // to detect if the token is empty.
+      // The Trim(false) is needed in order to make a cell ending in a semicolon
+      // followed by a comment followed by a semicolon work.
+      token.Trim(false);
+      token.Trim(true);
+      if(token.Length()>1)
+        m_tokens.Add(token);
       token = wxEmptyString;
     }
   }
   // There might be a last token in the string we still haven't added.
   // Let's trim() it first: This way MathCtrl::TryEvaluateNextInQueue()
   // will detect if the token is empty.
-  token.Trim(true).Trim(false);
-  if(token != wxEmptyString)
+  token.Trim(false);
+  token.Trim(true);
+  if(token.Length()>1)
     m_tokens.Add(token);
 }
 
@@ -234,7 +260,36 @@ GroupCell* EvaluationQueue::GetCell()
 wxString EvaluationQueue::GetCommand()
 {
   wxString retval;
+  m_userLabel = wxEmptyString;
   if(!m_tokens.IsEmpty())
+  {
     retval = m_tokens[0];
+
+    wxString userLabel;
+    int colonPos;
+    if((colonPos = retval.find(wxT(":")))!=wxNOT_FOUND)
+    {
+      userLabel = retval.Left(colonPos);
+      userLabel.Trim(true);
+      userLabel.Trim(false);
+      if((wxIsalpha(userLabel[0]))||(userLabel[0]==wxT('\\'))||(userLabel[0]==wxT('_')))
+      {
+        for(size_t i=0;i<userLabel.Length();i++)
+        {
+          if(userLabel[i]==wxT('\\'))
+            i++;
+          else
+          {
+            if((!wxIsalnum(userLabel[i]))&&(userLabel[i]!='_'))
+            {
+              userLabel = wxEmptyString;
+              break;
+            }
+          }
+        }
+        m_userLabel = userLabel;
+      } 
+    };
+  }
   return retval;
 }
