@@ -1,7 +1,7 @@
 // -*- mode: c++; c-file-style: "linux"; c-basic-offset: 2; indent-tabs-mode: nil -*-
 //
 //  Copyright (C) 2004-2015 Andrej Vodopivec <andrej.vodopivec@gmail.com>
-//            (C) 2014-2015 Gunter Königsmann <wxMaxima@physikbuch.de>
+//            (C) 2014-2016 Gunter Königsmann <wxMaxima@physikbuch.de>
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -200,6 +200,15 @@ wxString ExptCell::GetDiffPart()
   return s;
 }
 
+wxString ExptCell::ToMathML()
+{
+  return wxT("<msup>") +
+    m_baseCell -> ListToMathML() +
+    m_powCell -> ListToMathML() +
+    wxT("</msup>\n");
+//  return wxT("<apply><power/>") + m_baseCell->ListToMathML() + m_powCell->ListToMathML() + wxT("</apply>");
+}
+
 wxString ExptCell::ToXML()
 {
 //  if (m_isBroken)
