@@ -1,7 +1,7 @@
 // -*- mode: c++; c-file-style: "linux"; c-basic-offset: 2; indent-tabs-mode: nil -*-
 //
 //  Copyright (C) 2004-2015 Andrej Vodopivec <andrej.vodopivec@gmail.com>
-//            (C) 2014-2015 Gunter Königsmann <wxMaxima@physikbuch.de>
+//            (C) 2014-2016 Gunter Königsmann <wxMaxima@physikbuch.de>
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -297,7 +297,7 @@ wxString FracCell::ToTeX()
   {
     if (m_fracStyle == FC_CHOOSE)
     {
-      s = wxT("\\begin{pmatrix}") + m_num->ListToTeX() + wxT("\\cr ") +
+      s = wxT("\\begin{pmatrix}") + m_num->ListToTeX() + wxT("\\\\\n") +
           m_denom->ListToTeX() + wxT("\\end{pmatrix}");
     }
     else
@@ -309,13 +309,21 @@ wxString FracCell::ToTeX()
   return s;
 }
 
+wxString FracCell::ToMathML()
+{
+  return wxT("<mfrac>") +
+    m_num->ListToMathML() + 
+    m_denom->ListToMathML() + wxT("</mfrac>\n");
+}
+
 wxString FracCell::ToXML()
 {
-//  if( m_isBroken )
-//    return wxEmptyString;
   wxString s = ( m_fracStyle == FC_NORMAL || m_fracStyle == FC_DIFF )?
     _T("f"): _T("f line = \"no\"");
-  return _T("<") + s + _T("><r>") +
+  wxString diffStyle;
+  if(m_fracStyle == FC_DIFF)
+    diffStyle=wxT(" diffstyle=\"yes\"");
+  return _T("<") + s + diffStyle + _T("><r>") +
     m_num->ListToXML() + _T("</r><r>") +
     m_denom->ListToXML() + _T("</r></f>");
 }
