@@ -1,7 +1,7 @@
 // -*- mode: c++; c-file-style: "linux"; c-basic-offset: 2; indent-tabs-mode: nil -*-
 //
 //  Copyright (C) 2004-2015 Andrej Vodopivec <andrej.vodopivec@gmail.com>
-//            (C) 2014-2015 Gunter Königsmann <wxMaxima@physikbuch.de>
+//            (C) 2014-2016 Gunter Königsmann <wxMaxima@physikbuch.de>
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -133,7 +133,24 @@ wxString FunCell::ToTeX()
 {
   if (m_isBroken)
     return wxEmptyString;
-  wxString s = m_nameCell->ListToTeX() + m_argCell->ListToTeX();
+
+  wxString s;
+  
+  if(
+    (m_nameCell->ToString() == wxT("sin")) ||
+    (m_nameCell->ToString() == wxT("cos")) ||
+    (m_nameCell->ToString() == wxT("cosh")) ||
+    (m_nameCell->ToString() == wxT("cos")) ||
+    (m_nameCell->ToString() == wxT("log")) ||
+    (m_nameCell->ToString() == wxT("cot")) ||
+    (m_nameCell->ToString() == wxT("sec")) ||
+    (m_nameCell->ToString() == wxT("csc")) ||
+    (m_nameCell->ToString() == wxT("tan"))
+    ) 
+    s = wxT("\\")+m_nameCell->ToString()+wxT("{")+m_argCell->ListToTeX()+wxT("}");
+  else
+    s = m_nameCell->ListToTeX() + m_argCell->ListToTeX();
+        
   return s;
 }
 
@@ -145,6 +162,14 @@ wxString FunCell::ToXML()
     m_argCell->ListToXML() + _T("</fn>");
 }
 
+wxString FunCell::ToMathML()
+{
+//  if (m_isBroken)
+//    return wxEmptyString;
+  return wxT("<mrow>")+m_nameCell->ListToMathML() +
+    wxT("<mo>&#x2061;</mo>") + m_argCell->ListToMathML()+ wxT("</mrow>\n");
+}
+
 void FunCell::SelectInner(wxRect& rect, MathCell** first, MathCell** last)
 {
   *first = NULL;
