@@ -88,8 +88,9 @@ public:
   void RemoveOutput();
   // exporting
   wxString ToTeX(wxString imgDir, wxString filename, int *imgCounter);
+  wxString ToTeXCodeCell(wxString imgDir, wxString filename, int *imgCounter);
+  wxString ToTeXImage(MathCell *tmp, wxString imgDir, wxString filename, int *imgCounter);
   wxString ToTeX();
-  wxString PrepareForTeX(wxString text);
   //! Add Markdown to the TeX representation of input cells.
   wxString TeXMarkdown(wxString str);
   wxString ToXML();
