@@ -24,6 +24,7 @@
 
 #include "MathCell.h"
 #include <wx/image.h>
+#include <Image.h>
 
 #include <wx/filesys.h>
 #include <wx/fs_arc.h>
@@ -33,6 +34,7 @@ class ImgCell : public MathCell
 public:
   ImgCell();
   ImgCell(wxString image, bool remove = true, wxFileSystem *filesystem = NULL);
+  ImgCell(const wxBitmap &bitmap);
   ~ImgCell();
   void Destroy();
   void LoadImage(wxString image, bool remove = true);
@@ -42,8 +44,24 @@ public:
     *first = *last = this;
   }
   friend class SlideShow;
+  /*! Writes the image to a file
+
+    The image file that is written is either a bit-per-bit copy of the original
+    file loaded into the ImgCell - or in the case that there is no original file
+    a losslessly compressed png version of the bitmap.
+
+    See also GetExtension().
+   */
   wxSize ToImageFile(wxString filename);
-  void SetBitmap(wxBitmap bitmap);
+  /*! Removes the cached scaled image from memory
+
+    The scaled version of the image will be recreated automatically once it is 
+    needed.
+   */
+  virtual void ClearCache(){if(m_image)m_image->ClearCache();}
+  //! Sets the bitmap that is shown
+  void SetBitmap(const wxBitmap &bitmap);
+  //! Copies the cell to the system's clipboard
   bool CopyToClipboard();
   // These methods should only be used for saving wxmx files
   // and are shared with SlideShowCell.
@@ -51,9 +69,10 @@ public:
   static wxString WXMXGetNewFileName();
   static int WXMXImageCount() { return s_counter; }
   void DrawRectangle(bool draw) { m_drawRectangle = draw; }
+  //! Returns the file name extension that matches the image type
+  wxString GetExtension(){if(m_image)return m_image->GetExtension(); else return wxEmptyString;}
 protected:
-  wxBitmap *m_bitmap;
-  wxFileSystem *m_fileSystem;
+  Image *m_image;
   void RecalculateSize(CellParser& parser, int fontsize);
   void RecalculateWidths(CellParser& parser, int fontsize);
   void Draw(CellParser& parser, wxPoint point, int fontsize);
