@@ -1,7 +1,7 @@
 // -*- mode: c++; c-file-style: "linux"; c-basic-offset: 2; indent-tabs-mode: nil -*-
 //
 //  Copyright (C) 2004-2015 Andrej Vodopivec <andrej.vodopivec@gmail.com>
-//            (C) 2014-2015 Gunter Königsmann <wxMaxima@physikbuch.de>
+//            (C) 2014-2016 Gunter Königsmann <wxMaxima@physikbuch.de>
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -184,6 +184,21 @@ wxString LimitCell::ToTeX()
   return s;
 }
 
+wxString LimitCell::ToMathML()
+{
+  wxString base = m_base->ListToMathML();
+
+  wxString from;
+  if(m_under) from = m_under->ListToMathML();
+  
+  wxString retval;
+  if(from.IsEmpty())
+    retval = wxT("<mo>lim</mo>") + base;
+  else
+    retval = wxT("<munder><mo>lim</mo>") + from + wxT("</munder>\n");
+  return(retval);
+}
+
 wxString LimitCell::ToXML()
 {
   return _T("<lm><r>") + m_name->ListToXML() + _T("</r><r>") +
