@@ -26,6 +26,7 @@
 #include <wx/wx.h>
 #include <wx/aui/aui.h>
 #include <wx/textfile.h>
+#include <wx/fdrepdlg.h>
 #include <list>
 
 #include "MathCell.h"
@@ -43,7 +44,13 @@ This canvas contains all the math, title, image etc.- cells of the current sessi
  */
 class MathCtrl: public wxScrolledCanvas
 {
-   private:  
+private:
+  //! true, if we have the current focus.
+  bool m_hasFocus;
+  //! The last beginning for the area being drawn
+  size_t m_lastTop;
+  //! The last ending for the area being drawn
+  size_t m_lastBottom;
   /*! \defgroup UndoBufferFill
 
     These methods and classes contain the undo functionality for tree changes:
@@ -340,6 +347,10 @@ class MathCtrl: public wxScrolledCanvas
   void OnMouseMiddleUp(wxMouseEvent& event);
   void NumberSections();
   bool IsLesserGCType(int type, int comparedTo);
+  //! Finds the start of the current chapter/section/...
+  GroupCell *StartOfSectioningUnit(GroupCell *start);
+  //! Finds the end of the current chapter/section/...
+  GroupCell *EndOfSectioningUnit(GroupCell *start);
   //! Is called if a action from the autocomplete menu is selected
   void OnComplete(wxCommandEvent &event);
   wxPoint m_down;
@@ -397,8 +408,10 @@ class MathCtrl: public wxScrolledCanvas
   EditorCell *m_activeCell;
   EditorCell *m_cellMouseSelectionStartedIn;
   EditorCell *m_cellKeyboardSelectionStartedIn;
-  CellParser *m_selectionParser;
+  //! true = blink the cursor
   bool m_switchDisplayCaret;
+  //! Is the blinking vertically-drawn cursor currently visible?
+  bool m_hCaretBlinkVisible;
   /*! Is editing enabled?
 
     Editing is disabled while we are waiting for maxima.
@@ -417,12 +430,29 @@ class MathCtrl: public wxScrolledCanvas
 
 
 public:
+  //! The name of the currently-opened file
+  wxString m_currentFile;
+
+  /*! Make a few unicode characters interpretable by maxima.
+    
+    Does convert the not equal sign to a '#' and similar.
+
+    \todo We perhaps could think of only doing this outside of strings.
+   */
+  wxString UnicodeToMaxima(wxString s);
+  //! Unfold the cell that produced the error, if necessary and, if requested, scroll to it
+  void ScrollToError();
+  //! Get the last known GroupCell maxima was working on
+  GroupCell *GetLastWorkingGroup();
+  //! The find-and-replace-dialog
+  wxFindReplaceDialog *m_findDialog;
+  
   /*! True = schedule an update of the table of contents
     
     used by UpdateTableOfContents() and the idle task.
   */
   bool m_scheduleUpdateToc;
-  
+  //! Is the vertically-drawn cursor active?
   bool HCaretActive(){return m_hCaretActive;}
   /*! Can we merge the selected cells into one?
     
@@ -472,10 +502,12 @@ public:
     popid_add_comment,
     popid_insert_input,
     popid_copy_tex,
+    popid_copy_mathml,
     popid_image,
     popid_animation_save,
     popid_animation_start,
     popid_evaluate,
+    popid_evaluate_section,
     popid_merge_cells,
     popid_insert_text,
     popid_insert_title,
@@ -623,6 +655,8 @@ public:
   bool CopyCells();
   //! Copy the TeX representation of the current selection to the clipboard
   bool CopyTeX();
+  //! Copy the MathML representation of the current selection to the clipboard
+  bool CopyMathML();
   //! Copy a bitmap of the the current selection to the clipboard
   bool CopyBitmap();
   wxSize CopyToFile(wxString file);
@@ -750,14 +784,21 @@ public:
   void RemoveAllOutput(GroupCell* cell);
   // methods related to evaluation queue
 
+  //! Adds a group cell to the evaluation queue marking its contents as "outdated".
+  void AddToEvaluationQueue(GroupCell *cell);
+
   void AddDocumentToEvaluationQueue();
   
   //! Schedule all cells in the document for evaluation
   void AddEntireDocumentToEvaluationQueue();
   //! Schedule all cells stopping with the one the caret is in for evaluation
   void AddDocumentTillHereToEvaluationQueue();
-  //! Schedule all selected cells to be evaluated
+  //! Adds a chapter, a section or a subsection to the evaluation queue
+  void AddSectionToEvaluationQueue(GroupCell *start);
+  //! Schedule all cells in the selection to be evaluated
   void AddSelectionToEvaluationQueue();
+  //! Schedule all cells in a region to be evaluated  
+  void AddSelectionToEvaluationQueue(GroupCell *start,GroupCell *end);
   //! Schedule this cell for evaluation
   void AddCellToEvaluationQueue(GroupCell* gc);
   //! The list of cells that have to be evaluated
@@ -818,6 +859,8 @@ public:
     \retval true = maxima waits for the answer of a question.
   */
   bool QuestionPending(){return m_questionPrompt;}
+  //! Converts a wxm description into individual cells
+  GroupCell* CreateTreeFromWXMCode(wxArrayString *wxmLines);
 
     /*! Does maxima wait for the answer of a question?
 
