@@ -260,23 +260,30 @@ MathCell* MathParser::ParseFracTag(wxXmlNode* node)
   child = SkipWhitespaceNode(child);
   if (child)
   {
-    frac->SetNum(ParseTag(child, false));
+    MathCell *enumerator = ParseTag(child, false);
+    if(enumerator==NULL)
+      return NULL;
+    frac->SetNum(enumerator);
     child = GetNextTag(child);
-
-    if (child)
+    child = SkipWhitespaceNode(child);
+    if ((child != NULL) && (enumerator != NULL))
     {
-      frac->SetDenom(ParseTag(child, false));
-      frac->SetStyle(TS_VARIABLE);
-
-      if(node->GetAttribute(wxT("line")) == wxT("no"))
+      MathCell *denominator = ParseTag(child, false);
+      if(denominator != NULL)
       {
-        frac->SetFracStyle(FracCell::FC_CHOOSE);
+        frac->SetDenom(denominator);
+        frac->SetStyle(TS_VARIABLE);
+        
+        if(node->GetAttribute(wxT("line")) == wxT("no"))
+        {
+          frac->SetFracStyle(FracCell::FC_CHOOSE);
+        }
+        if(node->GetAttribute(wxT("diffstyle")) == wxT("yes"))
+          frac->SetFracStyle(FracCell::FC_DIFF);
+        frac->SetType(m_ParserStyle);
+        frac->SetupBreakUps();
+        return frac;
       }
-      if(node->GetAttribute(wxT("diffstyle")) == wxT("yes"))
-        frac->SetFracStyle(FracCell::FC_DIFF);
-      frac->SetType(m_ParserStyle);
-      frac->SetupBreakUps();
-      return frac;
     }
   }
 
@@ -658,8 +665,26 @@ MathCell* MathParser::ParseIntTag(wxXmlNode* node)
   wxXmlNode* child = node->GetChildren();
   child = SkipWhitespaceNode(child);
   in->SetHighlight(m_highlight);
-  if (node->GetAttributes() == NULL)
+  wxString definiteAtt=node->GetAttribute(wxT("def"),wxT("true"));
+  if (definiteAtt != wxT("true"))
   {
+    // A indefinite integral
+    if (child)
+    {
+      in->SetBase(ParseTag(child, false));
+      child = GetNextTag(child);
+      if (child)
+      {
+        in->SetVar(ParseTag(child, true));
+        in->SetType(m_ParserStyle);
+        in->SetStyle(TS_VARIABLE);
+        return in;
+      }
+    }
+  }
+  else
+  {
+    // A Definite integral
     in->SetIntStyle(IntCell::INT_DEF);
     if (child)
     {
@@ -684,21 +709,6 @@ MathCell* MathParser::ParseIntTag(wxXmlNode* node)
       }
     }
   }
-  else
-  {
-    if (child)
-    {
-      in->SetBase(ParseTag(child, false));
-      child = GetNextTag(child);
-      if (child)
-      {
-        in->SetVar(ParseTag(child, true));
-        in->SetType(m_ParserStyle);
-        in->SetStyle(TS_VARIABLE);
-        return in;
-      }
-    }
-  }
   delete in;
   return NULL;
 }
