@@ -61,7 +61,6 @@ bool MathPrintout::OnPrintPage(int num)
   int marginX, marginY;
   GetPageMargins(&marginX, &marginY);
 
-
   ppiScale = GetPPIScale();
   GetScreenScale(&screenScaleX, &screenScaleY);
 
@@ -93,9 +92,14 @@ bool MathPrintout::OnPrintPage(int num)
     CellParser parser(*dc, ppiScale);
 
     parser.SetIndent(marginX);
+    parser.SetPrinter(true);
 
     while (tmp != NULL && tmp->GetGroupType() != GC_TYPE_PAGEBREAK)
     {
+      // The following line seems to misteriously fix the "subsequent text
+      // cells aren't printed" problem on linux.
+      // No Idea why, though.
+      dc->SetPen(wxPen(wxT("light grey"), 1, wxPENSTYLE_SOLID));
       tmp->Draw(parser, point, fontsize);
       if (tmp->m_next != NULL) {
         point.x = marginX;
