@@ -61,7 +61,7 @@ Plot2DWiz::Plot2DWiz(wxWindow* parent, int id, const wxString& title,
       _("default"),
       _("inline"),
       wxT("gnuplot"),
-      wxT("openmath")
+      wxT("xmaxima")
     };
   combo_box_1 = new wxComboBox(this, -1, wxEmptyString, wxDefaultPosition,
                                wxSize(150, -1), 4,
