@@ -1,7 +1,7 @@
 // -*- mode: c++; c-file-style: "linux"; c-basic-offset: 2; indent-tabs-mode: nil -*-
 //
 //  Copyright (C) 2004-2015 Andrej Vodopivec <andrej.vodopivec@gmail.com>
-//            (C) 2014-2015 Gunter Königsmann <wxMaxima@physikbuch.de>
+//            (C) 2014-2016 Gunter Königsmann <wxMaxima@physikbuch.de>
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -180,6 +180,10 @@ void SqrtCell::Draw(CellParser& parser, wxPoint point, int fontsize)
         int yBottom = point.y + m_innerCell->GetMaxDrop() - 3.2*m_signTop;
         int yTop = point.y - m_innerCell->GetMaxCenter() - m_signTop;
         int dy = m_signSize / 10;
+        wxASSERT_MSG((yTop != 0) || (yBottom != 0),_("Font issue? The contents of a sqrt() has the size 0."));
+        wxASSERT_MSG(dy>0,_("Font issue: The sqrt() sign has the size 0! Installing http://www.math.union.edu/~dpvc/jsmath/download/jsMath-fonts.html and checking \"Use JSmath fonts\" in the configuration dialogue should be a workaround."));
+        if(dy <= 0)
+          dy = 1;
         dc.DrawText(wxT("t"),
             point.x,
             yBottom);
@@ -252,6 +256,11 @@ wxString SqrtCell::ToTeX()
   return wxT("\\sqrt{") + m_innerCell->ListToTeX() + wxT("}");
 }
 
+wxString SqrtCell::ToMathML()
+{
+  return wxT("<msqrt>") + m_innerCell->ListToMathML() +wxT("</msqrt>\n");
+}
+
 wxString SqrtCell::ToXML()
 {
 //  if (m_isBroken)
