@@ -1,7 +1,7 @@
 // -*- mode: c++; c-file-style: "linux"; c-basic-offset: 2; indent-tabs-mode: nil -*-
 //
 //  Copyright (C) 2004-2015 Andrej Vodopivec <andrej.vodopivec@gmail.com>
-//            (C) 2014-2015 Gunter Königsmann <wxMaxima@physikbuch.de>
+//            (C) 2014-2016 Gunter Königsmann <wxMaxima@physikbuch.de>
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -149,10 +149,23 @@ wxString SubCell::ToTeX()
   return s;
 }
 
+wxString SubCell::ToMathML()
+{
+  return wxT("<msub>") +
+    m_baseCell -> ListToMathML() +
+    m_indexCell -> ListToMathML() +
+    wxT("</msub>\n");
+}
+
 wxString SubCell::ToXML()
 {
-  return _T("<i><r>") + m_baseCell->ListToXML() + _T("</r><r>") +
-    m_indexCell->ListToXML() + _T("</r></i>");
+  if (m_altCopyText == wxEmptyString)
+  {
+    return _T("<i><r>") + m_baseCell->ListToXML() + _T("</r><r>") +
+      m_indexCell->ListToXML() + _T("</r></i>");
+  }
+  return _T("<i altCopy=\"" + m_altCopyText + "\"><r>") + m_baseCell->ListToXML() + _T("</r><r>") +
+      m_indexCell->ListToXML() + _T("</r></i>");
 }
 
 void SubCell::SelectInner(wxRect& rect, MathCell **first, MathCell **last)
