@@ -1,7 +1,7 @@
 // -*- mode: c++; c-file-style: "linux"; c-basic-offset: 2; indent-tabs-mode: nil -*-
 //
 //  Copyright (C) 2004-2015 Andrej Vodopivec <andrej.vodopivec@gmail.com>
-//            (C) 2014-2015 Gunter Königsmann <wxMaxima@physikbuch.de>
+//            (C) 2014-2016 Gunter Königsmann <wxMaxima@physikbuch.de>
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -280,7 +280,7 @@ wxString SumCell::ToString()
   s += m_base->ListToString();
 
   MathCell* tmp = m_under;
-  wxString var = tmp->ListToString();
+  wxString var = tmp->ToString();
   wxString from;
   tmp = tmp->m_next;
   if (tmp != NULL)
@@ -311,7 +311,11 @@ wxString SumCell::ToTeX()
   wxString to = m_over->ListToTeX();
   if (to.Length())
     s += wxT("^{") + to + wxT("}");
+
+
+  s += wxT("{\\left. ");
   s += m_base->ListToTeX();
+  s += wxT("\\right.}");
   return s;
 }
 
@@ -329,6 +333,51 @@ wxString SumCell::ToXML()
     m_base->ListToXML() + _T("</r></sm>");
 }
 
+wxString SumCell::ToMathML()
+{
+  wxString base = m_base->ListToMathML();
+
+  wxString from;
+  if(m_under) from = m_under->ListToMathML();
+  
+  wxString to;
+  if(m_over) to = m_over->ListToMathML();
+
+  wxString retval;
+
+  if (m_sumStyle == SM_SUM)
+  {
+//    retval = wxT("<apply><sum/>");
+//    if(!from.IsEmpty())
+//      retval += wxT("<lowlimit>") + m_under->ListToMathML() + wxT("</lowlimit>");
+//    if(!to.IsEmpty())
+//      retval += wxT("<uplimit>") + m_over->ListToMathML() + wxT("</uplimit>");
+//    retval += m_base->ListToMathML() + wxT("</apply>");
+      if(from.IsEmpty() && to.IsEmpty())
+        retval = wxT("<mo>&#x2211;</mo>") + base;
+      if(from.IsEmpty() && !to.IsEmpty())
+        retval = wxT("<mover><mo>&#x2211;</mo>") + to + wxT("</mover>") + base;
+      if(!from.IsEmpty() && to.IsEmpty())
+        retval = wxT("<munder><mo>&#x2211;</mo>") + from + wxT("</munder>") + base;
+      if(!from.IsEmpty() && !to.IsEmpty())
+        retval = wxT("<munderover><mo>&#x2211;</mo>") + from + to + wxT("</munderover>") + base;
+  }
+  else
+  {
+    // A product
+      if(from.IsEmpty() && to.IsEmpty())
+        retval = wxT("<mo>&#x220F;</mo>") + base;
+      if(from.IsEmpty() && !to.IsEmpty())
+        retval = wxT("<mover><mo>&#x220F;</mo>") + to + wxT("</mover>") + base;
+      if(!from.IsEmpty() && to.IsEmpty())
+        retval = wxT("<munder><mo>&#x220F;</mo>") + from + wxT("</munder>") + base;
+      if(!from.IsEmpty() && !to.IsEmpty())
+        retval = wxT("<munderover><mo>&#x220F;</mo>") + from + to + wxT("</munderover>") + base;
+  }
+  return(wxT("<mrow>")+retval+wxT("</mrow>"));
+}
+
+
 void SumCell::SelectInner(wxRect& rect, MathCell** first, MathCell** last)
 {
   *first = NULL;
