@@ -1,7 +1,7 @@
 // -*- mode: c++; c-file-style: "linux"; c-basic-offset: 2; indent-tabs-mode: nil -*-
 //
 //  Copyright (C) 2004-2015 Andrej Vodopivec <andrej.vodopivec@gmail.com>
-//            (C) 2014-2015 Gunter Königsmann <wxMaxima@physikbuch.de>
+//            (C) 2014-2016 Gunter Königsmann <wxMaxima@physikbuch.de>
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -38,6 +38,7 @@ public:
   void SetFont(CellParser& parser, int fontsize);
   wxString ToString();
   wxString ToTeX();
+  wxString ToMathML();
   wxString ToXML();
   wxString GetDiffPart();
   bool IsOperator();
@@ -63,6 +64,10 @@ protected:
   int m_fontSizeTeX;
   int m_fontSizeLabel;
   int m_labelWidth, m_labelHeight;
+private:
+  //! Produces a text sample that determines the label width
+  wxString LabelWidthText();
+
 };
 
 #endif // TEXTCELL_H
