@@ -27,19 +27,41 @@
 #include <wx/filename.h>
 
 #if defined (__WXMSW__) || defined (__WXMAC__)
-wxImage ToolBar::GetImage(wxString img)
+wxImage ToolBar::GetImage(wxString name)
 {
   Dirstructure dirstructure;
-  return wxImage(dirstructure.ConfigToolbarDir() + img + wxT(".png"));
+  wxImage img = wxImage(dirstructure.ConfigToolbarDir() + name + wxT(".png"));
+  // We want to scale the images according to the display's resolution.
+  // But we want to do so in discrete steps as scaling bitmaps by odd
+  // factors will add visible antialiassing to things that are clearly
+  // meant to be sharp lines.
+  int resolutionMultiplier = wxGetDisplayPPI().x/72;
+  int imgWidth = 24 * resolutionMultiplier;
+  int width,height;
+  wxDisplaySize(&width,&height);
+  if(width <= 800)
+    imgWidth = 24;
+  if(imgWidth < 24)
+    imgWidth = 24;
+
+  double scaleFactor = (double)imgWidth / img.GetWidth();
+  img.Rescale(imgWidth,img.GetHeight()*scaleFactor,wxIMAGE_QUALITY_HIGH );
+  return img;
 }
 #else
-wxBitmap ToolBar::GetImage(wxString img)
+wxBitmap ToolBar::GetImage(wxString name)
 {
-#if defined (__WXMSW__) || defined (__WXMAC__)
-  return wxImage(dirstructure.ConfigToolbarDir() + img + wxT(".png"));
-#else
-  return wxArtProvider::GetBitmap(img,wxART_TOOLBAR);
-#endif
+  wxImage img;
+  img = wxArtProvider::GetBitmap(name,wxART_TOOLBAR).ConvertToImage();
+/*
+  I think scaling is unnecessary in this case since wxArtProvider should consider
+  the display's dpi number automagically. => Commented out the following lines:
+
+  double imgWidth = wxGetDisplayPPI().x*24/72;
+  double scaleFactor = imgWidth / img.GetWidth();
+  img.Rescale(img.GetWidth()*scaleFactor,img.GetHeight()*scaleFactor,wxIMAGE_QUALITY_HIGH );
+*/
+  return img;
 }
 #endif
 
@@ -48,6 +70,24 @@ ToolBar::~ToolBar()
   m_plotSlider = NULL;
 }
 
+void ToolBar::UpdateSlider(SlideShow *cell)
+{
+  int slideShowDisplayedIndex = cell->GetDisplayedIndex();
+  int slideShowMaxIndex = cell->Length();
+
+  if((m_slideShowDisplayedIndex != slideShowDisplayedIndex) || (m_slideShowMaxIndex != slideShowMaxIndex))
+  {
+    m_slideShowMaxIndex = slideShowMaxIndex;
+    m_slideShowDisplayedIndex = slideShowDisplayedIndex;
+    if(m_plotSlider != NULL)
+    {
+      m_plotSlider->SetRange(0, cell->Length() - 1);
+      m_plotSlider->SetValue(cell->GetDisplayedIndex());
+      m_plotSlider->SetToolTip(wxString::Format(_("Frame %i of %i"),cell->GetDisplayedIndex() + 1,cell->Length()));
+    }
+  }
+}
+
 ToolBar::ToolBar(wxToolBar *tbar)
 {
   m_canCopy_old = true;
@@ -147,9 +187,18 @@ ToolBar::ToolBar(wxToolBar *tbar)
                      m_PlayButton,
                      _("Start or stop the currently selected animation that has been created with the with_slider class of commands"));
   m_toolBar->EnableTool(tb_animation_startStop,false);
+  int sliderWidth = wxGetDisplayPPI().x*200/72;
+  int width,height;
+  wxDisplaySize(&width,&height);
+  if(width<800)
+    sliderWidth = MIN(sliderWidth,100);
   m_plotSlider = new wxSlider(m_toolBar, plot_slider_id, 0, 0, 10,
-			      wxDefaultPosition, wxSize(200, -1),
+			      wxDefaultPosition, wxSize(sliderWidth, -1),
 			      wxSL_HORIZONTAL | !wxSL_AUTOTICKS);
+  m_plotSlider->SetToolTip(_("After clicking on animations created with with_slider_draw() or similar this slider allows to change the current frame."));
+  m_plotSlider->Enable(false);
+  m_slideShowMaxIndex = -1;
+  m_slideShowDisplayedIndex = -1;
   m_toolBar->AddControl(m_plotSlider);
 #ifndef __WXMAC__
   m_toolBar->AddSeparator();
@@ -190,6 +239,10 @@ void ToolBar::AnimationButtonState(AnimationStartStopState state)
     case Inactive:
       m_toolBar->EnableTool(tb_animation_startStop,false);
       m_plotSlider->Enable(false);
+      m_plotSlider->SetToolTip(_("After clicking on animations created with with_slider_draw() or similar this slider allows to change the current frame."));
+      m_slideShowMaxIndex = -1;
+      m_slideShowDisplayedIndex = -1;
+
       if(m_AnimationStartStopState==Running)
       {
 #ifndef __WXMSW__
