@@ -47,6 +47,7 @@ wxMaximaFrame::wxMaximaFrame(wxWindow* parent, int id, const wxString& title,
   // The table of contents
   m_console->m_structure = new Structure(this, -1);
 
+  m_xmlInspector = new XmlInspector(this, -1);
   SetupMenu();
 
   CreateStatusBar(2);
@@ -60,28 +61,21 @@ wxMaximaFrame::wxMaximaFrame(wxWindow* parent, int id, const wxString& title,
   StatusMaximaBusy(waiting);
 
   // Add some shortcuts that aren't automatically set by menu entries.
-#if defined __WXMSW__
-  wxAcceleratorEntry entries[7];
+  wxAcceleratorEntry entries[11];
   entries[0].Set(wxACCEL_CTRL,  WXK_TAB,    menu_autocomplete);
   entries[1].Set(wxACCEL_CTRL,  WXK_SPACE,  menu_autocomplete);
   entries[2].Set(wxACCEL_CTRL|wxACCEL_SHIFT,  WXK_TAB,    menu_autocomplete_templates);
   entries[3].Set(wxACCEL_CTRL|wxACCEL_SHIFT,  WXK_SPACE,  menu_autocomplete_templates);
-  entries[4].Set(wxACCEL_CTRL,  wxT('+'),   MathCtrl::menu_zoom_in);
-  entries[5].Set(wxACCEL_CTRL,  wxT('-'),   MathCtrl::menu_zoom_out);
-  entries[6].Set(wxACCEL_CTRL,  WXK_RETURN, menu_evaluate);
-  wxAcceleratorTable accel(7, entries);
+  entries[4].Set(wxACCEL_ALT,  wxT('I'),   MathCtrl::menu_zoom_in);
+  entries[5].Set(wxACCEL_ALT,  wxT('O'),   MathCtrl::menu_zoom_out);
+  entries[6].Set(wxACCEL_CTRL|wxACCEL_SHIFT, WXK_ESCAPE,  menu_convert_to_code);
+  entries[6].Set(wxACCEL_CTRL|wxACCEL_SHIFT, wxT('1'),  menu_convert_to_comment);
+  entries[7].Set(wxACCEL_CTRL|wxACCEL_SHIFT, wxT('2'),  menu_convert_to_title);
+  entries[8].Set(wxACCEL_CTRL|wxACCEL_SHIFT, wxT('3'),  menu_convert_to_section);
+  entries[9].Set(wxACCEL_CTRL|wxACCEL_SHIFT, wxT('4'),  menu_convert_to_subsection);
+  entries[10].Set(wxACCEL_CTRL|wxACCEL_SHIFT, wxT('5'),  menu_convert_to_subsubsection);
+  wxAcceleratorTable accel(11, entries);
   SetAcceleratorTable(accel);
-#else
-  wxAcceleratorEntry entries[6];
-  entries[0].Set(wxACCEL_CTRL,  WXK_TAB, menu_autocomplete);
-  entries[1].Set(wxACCEL_CTRL,  WXK_SPACE, menu_autocomplete);
-  entries[2].Set(wxACCEL_CTRL|wxACCEL_SHIFT,  WXK_TAB,    menu_autocomplete_templates);
-  entries[3].Set(wxACCEL_CTRL|wxACCEL_SHIFT,  WXK_SPACE,  menu_autocomplete_templates);
-  entries[4].Set(wxACCEL_CTRL,  wxT('+'), MathCtrl::menu_zoom_in);
-  entries[5].Set(wxACCEL_CTRL,  wxT('-'), MathCtrl::menu_zoom_out);
-  wxAcceleratorTable accel(6, entries);
-  SetAcceleratorTable(accel);
-#endif
 
   set_properties();
   do_layout();
@@ -288,15 +282,30 @@ void wxMaximaFrame::do_layout()
                     Show(false).
                     TopDockable(true).
                     BottomDockable(true).
+                    LeftDockable(true).
+                    RightDockable(true).
                     PaneBorder(true).
                     Right());
 
   m_manager.AddPane(m_console->m_structure,
                     wxAuiPaneInfo().Name(wxT("structure")).
                     Caption(_("Table of Contents")).
+                    Show(true).
+                    TopDockable(true).
+                    BottomDockable(true).
+                    LeftDockable(true).
+                    RightDockable(true).
+                    PaneBorder(true).
+                    Right());
+
+  m_manager.AddPane(m_xmlInspector,
+                    wxAuiPaneInfo().Name(wxT("XmlInspector")).
+                    Caption(_("Raw XML monitor")).
                     Show(false).
                     TopDockable(true).
                     BottomDockable(true).
+                    LeftDockable(true).
+                    RightDockable(true).
                     PaneBorder(true).
                     Right());
 
@@ -306,16 +315,57 @@ void wxMaximaFrame::do_layout()
                     Show(false).
                     TopDockable(true).
                     BottomDockable(true).
+                    LeftDockable(true).
+                    RightDockable(true).
                     PaneBorder(true).
                     Fixed().
                     Left());
 
+  wxPanel *greekPane = CreateGreekPane();
+#ifdef wxUSE_UNICODE
+  m_manager.AddPane(greekPane,
+                    wxAuiPaneInfo().Name(wxT("greek")).
+                    Caption(_("Greek letters")).
+                    Show(false).
+                    DockFixed(false).
+                    Gripper(true).
+                    TopDockable(true).
+                    BottomDockable(true).
+                    LeftDockable(true).
+                    RightDockable(true).
+                    PaneBorder(true).
+                    MinSize(greekPane->GetEffectiveMinSize()).
+                    BestSize(greekPane->GetEffectiveMinSize()).
+                    MaxSize(greekPane->GetEffectiveMinSize()).
+                    FloatingSize(greekPane->GetEffectiveMinSize()).
+                    Left());
+
+  wxPanel *symbolsPane = CreateSymbolsPane();
+  m_manager.AddPane(symbolsPane,
+                    wxAuiPaneInfo().Name(wxT("symbols")).
+                    Caption(_("Mathematical Symbols")).
+                    Show(false).
+                    DockFixed(false).
+                    Gripper(true).
+                    TopDockable(true).
+                    BottomDockable(true).
+                    LeftDockable(true).
+                    RightDockable(true).
+                    PaneBorder(true).
+                    MinSize(symbolsPane->GetEffectiveMinSize()).
+                    BestSize(symbolsPane->GetEffectiveMinSize()).
+                    MaxSize(symbolsPane->GetEffectiveMinSize()).
+                    FloatingSize(symbolsPane->GetEffectiveMinSize()).
+                    Left());
+#endif
   m_manager.AddPane(CreateMathPane(),
                     wxAuiPaneInfo().Name(wxT("math")).
                     Caption(_("General Math")).
                     Show(false).
                     TopDockable(true).
                     BottomDockable(true).
+                    LeftDockable(true).
+                    RightDockable(true).
                     PaneBorder(true).
                     Fixed().
                     Left());
@@ -326,21 +376,33 @@ void wxMaximaFrame::do_layout()
                     Show(false).
                     TopDockable(true).
                     BottomDockable(true).
+                    LeftDockable(true).
+                    RightDockable(true).
                     PaneBorder(true).
                     Fixed().
                     Left());
 
   wxConfigBase *config = wxConfig::Get();
-  bool loadPanes = false;
+  bool loadPanes = true;
+  wxString perspective;
   config->Read(wxT("AUI/savePanes"), &loadPanes);
+  config->Read(wxT("AUI/perspective"), &perspective);
 
-  if (loadPanes) {
-    wxString perspective;
+  if (loadPanes && !perspective.IsEmpty()) {
+    m_manager.LoadPerspective(perspective);
     bool toolbar = true;
-    if (config->Read(wxT("AUI/perspective"), &perspective))
-      m_manager.LoadPerspective(perspective);
     config->Read(wxT("AUI/toolbar"), &toolbar);
     ShowToolBar(toolbar);
+    m_manager.GetPane(wxT("greek"))=m_manager.GetPane(wxT("greek")).
+      MinSize(greekPane->GetEffectiveMinSize()).
+      BestSize(greekPane->GetEffectiveMinSize()).
+      MaxSize(greekPane->GetEffectiveMinSize());
+
+    m_manager.GetPane(wxT("symbols"))=m_manager.GetPane(wxT("symbols")).
+      MinSize(symbolsPane->GetEffectiveMinSize()).
+      BestSize(symbolsPane->GetEffectiveMinSize()).
+      MaxSize(symbolsPane->GetEffectiveMinSize());
+
   }
   else
     m_manager.Update();
@@ -417,6 +479,9 @@ void wxMaximaFrame::SetupMenu()
   m_EditMenu->Append(menu_copy_tex_from_console, _("Copy as LaTeX"),
                      _("Copy selection from document in LaTeX format"),
                      wxITEM_NORMAL);
+  m_EditMenu->Append(MathCtrl::popid_copy_mathml, _("Copy as MathML"),
+                     _("Copy selection from document in a MathML format many word processors can display as 2d equation"),
+                     wxITEM_NORMAL);
 #if defined __WXMSW__ || defined __WXMAC__
   m_EditMenu->Append(menu_copy_as_bitmap, _("Copy as Image"),
                      _("Copy selection from document as an image"),
@@ -440,9 +505,35 @@ void wxMaximaFrame::SetupMenu()
                      _("Comment out the currently selected text"),
                      wxITEM_NORMAL);
   m_EditMenu->AppendSeparator();
-  APPEND_MENU_ITEM(m_EditMenu, MathCtrl::menu_zoom_in, _("Zoom &In\tAlt-I"),
+#if defined __WXMAC__
+  APPEND_MENU_ITEM(m_EditMenu, wxID_PREFERENCES, _("Preferences...\tCtrl+,"),
+                   _("Configure wxMaxima"), wxT("gtk-preferences"));
+#else
+  APPEND_MENU_ITEM(m_EditMenu, wxID_PREFERENCES, _("C&onfigure"),
+                   _("Configure wxMaxima"), wxT("gtk-preferences"));
+#endif
+  m_MenuBar->Append(m_EditMenu, _("&Edit"));
+
+  // panes
+  m_Maxima_Panes_Sub = new wxMenu;
+  m_Maxima_Panes_Sub->AppendCheckItem(menu_show_toolbar, _("Main Toolbar\tAlt-Shift-B"));
+  m_Maxima_Panes_Sub->AppendSeparator();
+  m_Maxima_Panes_Sub->AppendCheckItem(menu_pane_math, _("General Math\tAlt-Shift-M"));
+  m_Maxima_Panes_Sub->AppendCheckItem(menu_pane_stats, _("Statistics\tAlt-Shift-S"));
+#ifdef wxUSE_UNICODE
+  m_Maxima_Panes_Sub->AppendCheckItem(menu_pane_greek, _("Greek letters\tAlt-Shift-G"));
+  m_Maxima_Panes_Sub->AppendCheckItem(menu_pane_symbols, _("Symbols\tAlt-Shift-Y"));
+#endif
+  m_Maxima_Panes_Sub->AppendCheckItem(menu_pane_history, _("History\tAlt-Shift-I"));
+  m_Maxima_Panes_Sub->AppendCheckItem(menu_pane_structure,  _("Table of contents\tAlt-Shift-T"));
+  m_Maxima_Panes_Sub->AppendCheckItem(menu_pane_xmlInspector,  _("XML Inspector"));
+  m_Maxima_Panes_Sub->AppendCheckItem(menu_pane_format, _("Insert Cell\tAlt-Shift-C"));
+  m_Maxima_Panes_Sub->AppendSeparator();
+  m_Maxima_Panes_Sub->Append(menu_pane_hideall, _("Hide All Toolbars\tAlt-Shift--"), _("Hide all panes"), wxITEM_NORMAL);
+  m_Maxima_Panes_Sub->AppendSeparator();
+  APPEND_MENU_ITEM(m_Maxima_Panes_Sub, MathCtrl::menu_zoom_in, _("Zoom &In\tCtrl-+"),
                    _("Zoom in 10%"), wxT("gtk-zoom-in"));
-  APPEND_MENU_ITEM(m_EditMenu, MathCtrl::menu_zoom_out, _("Zoom Ou&t\tAlt-O"),
+  APPEND_MENU_ITEM(m_Maxima_Panes_Sub, MathCtrl::menu_zoom_out, _("Zoom Ou&t\tCtrl--"),
                    _("Zoom out 10%"), wxT("gtk-zoom-out"));
   // zoom submenu
   m_Edit_Zoom_Sub = new wxMenu;
@@ -453,20 +544,14 @@ void wxMaximaFrame::SetupMenu()
   m_Edit_Zoom_Sub->Append(menu_zoom_200, wxT("200%"), _("Set zoom to 200%"), wxITEM_NORMAL);
   m_Edit_Zoom_Sub->Append(menu_zoom_300, wxT("300%"), _("Set zoom to 300%"), wxITEM_NORMAL);
 
-  m_EditMenu->Append(wxNewId(), _("Set Zoom"), m_Edit_Zoom_Sub, _("Set Zoom"));
-  m_EditMenu->Append(menu_fullscreen, _("Full Screen\tAlt-Enter"),
+  m_Maxima_Panes_Sub->Append(wxNewId(), _("Set Zoom"), m_Edit_Zoom_Sub, _("Set Zoom"));
+  m_Maxima_Panes_Sub->Append(menu_fullscreen, _("Full Screen\tAlt-Enter"),
                      _("Toggle full screen editing"),
                      wxITEM_NORMAL);
-  m_EditMenu->AppendSeparator();
-#if defined __WXMAC__
-  APPEND_MENU_ITEM(m_EditMenu, wxID_PREFERENCES, _("Preferences...\tCtrl+,"),
-                   _("Configure wxMaxima"), wxT("gtk-preferences"));
-#else
-  APPEND_MENU_ITEM(m_EditMenu, wxID_PREFERENCES, _("C&onfigure"),
-                   _("Configure wxMaxima"), wxT("gtk-preferences"));
-#endif
-  m_MenuBar->Append(m_EditMenu, _("&Edit"));
 
+  m_MenuBar->Append(m_Maxima_Panes_Sub,_("View"));
+
+  
   // Cell menu
   m_CellMenu = new wxMenu;
   m_CellMenu->Append(menu_evaluate, _("Evaluate Cell(s)"),
@@ -527,22 +612,6 @@ void wxMaximaFrame::SetupMenu()
   // Maxima menu
   m_MaximaMenu = new wxMenu;
 
-  // panes
-  m_Maxima_Panes_Sub = new wxMenu;
-  m_Maxima_Panes_Sub->Append(menu_pane_hideall, _("Hide All\tAlt-Shift--"), _("Hide all panes"), wxITEM_NORMAL);
-  m_Maxima_Panes_Sub->AppendSeparator();
-  m_Maxima_Panes_Sub->AppendCheckItem(menu_pane_math, _("General Math\tAlt-Shift-M"));
-  m_Maxima_Panes_Sub->AppendCheckItem(menu_pane_stats, _("Statistics\tAlt-Shift-S"));
-  m_Maxima_Panes_Sub->AppendCheckItem(menu_pane_history, _("History\tAlt-Shift-I"));
-  m_Maxima_Panes_Sub->AppendCheckItem(menu_pane_structure,  _("Table of contents\tAlt-Shift-T"));
-  m_Maxima_Panes_Sub->AppendCheckItem(menu_pane_format, _("Insert Cell\tAlt-Shift-C"));
-  m_Maxima_Panes_Sub->AppendSeparator();
-  m_Maxima_Panes_Sub->AppendCheckItem(menu_show_toolbar, _("Toolbar\tAlt-Shift-B"));
-  m_MaximaMenu->Append(wxNewId(), _("Panes"), m_Maxima_Panes_Sub);
-
-  m_MaximaMenu->AppendSeparator();
-
-
 #if defined (__WXMAC__)
   APPEND_MENU_ITEM(m_MaximaMenu, menu_interrupt_id,
                    _("&Interrupt\tCtrl-."), // command-. interrupts (mac standard)
@@ -669,7 +738,7 @@ void wxMaximaFrame::SetupMenu()
                          _("Make list from expression"), wxITEM_NORMAL);
   m_Algebra_Menu->Append(menu_apply, _("&Apply to List..."),
                          _("Apply function to a list"), wxITEM_NORMAL);
-  m_Algebra_Menu->Append(menu_map, _("&Map to List..."),
+  m_Algebra_Menu->Append(menu_map, _("&Map to List(s)..."),
                          _("Map function to a list"), wxITEM_NORMAL);
   m_Algebra_Menu->Append(menu_map_mat, _("Ma&p to Matrix..."),
                          _("Map function to a matrix"), wxITEM_NORMAL);
@@ -991,9 +1060,20 @@ bool wxMaximaFrame::IsPaneDisplayed(Event id)
   case menu_pane_structure:
     displayed = m_manager.GetPane(wxT("structure")).IsShown();
     break;
+  case menu_pane_xmlInspector:
+    displayed = m_manager.GetPane(wxT("XmlInspector")).IsShown();
+    break;
   case menu_pane_stats:
     displayed = m_manager.GetPane(wxT("stats")).IsShown();
     break;
+#ifdef wxUSE_UNICODE
+  case menu_pane_greek:
+    displayed = m_manager.GetPane(wxT("greek")).IsShown();
+    break;
+  case menu_pane_symbols:
+    displayed = m_manager.GetPane(wxT("symbols")).IsShown();
+    break;
+#endif
   case menu_pane_format:
     displayed = m_manager.GetPane(wxT("format")).IsShown();
     break;
@@ -1015,14 +1095,23 @@ void wxMaximaFrame::ShowPane(Event id, bool show)
     m_manager.GetPane(wxT("history")).Show(show);
     break;
   case menu_pane_structure:
-  {
     m_manager.GetPane(wxT("structure")).Show(show);
     m_console->m_structure->Update(m_console->GetTree(),m_console->GetHCaret());
-  }
-  break;
+    break;
+  case menu_pane_xmlInspector:
+    m_manager.GetPane(wxT("XmlInspector")).Show(show);
+    break;
   case menu_pane_stats:
     m_manager.GetPane(wxT("stats")).Show(show);
     break;
+#ifdef wxUSE_UNICODE
+  case menu_pane_greek:
+    m_manager.GetPane(wxT("greek")).Show(show);
+    break;
+  case menu_pane_symbols:
+    m_manager.GetPane(wxT("symbols")).Show(show);
+    break;
+#endif
   case menu_pane_format:
     m_manager.GetPane(wxT("format")).Show(show);
     break;
@@ -1030,8 +1119,14 @@ void wxMaximaFrame::ShowPane(Event id, bool show)
     m_manager.GetPane(wxT("math")).Show(false);
     m_manager.GetPane(wxT("history")).Show(false);
     m_manager.GetPane(wxT("structure")).Show(false);
+    m_manager.GetPane(wxT("XmlInspector")).Show(false);
     m_manager.GetPane(wxT("stats")).Show(false);
+#ifdef wxUSE_UNICODE
+    m_manager.GetPane(wxT("greek")).Show(false);
+    m_manager.GetPane(wxT("symbols")).Show(false);
+#endif
     m_manager.GetPane(wxT("format")).Show(false);
+    ShowToolBar(false);
     break;
   default:
     wxASSERT(false);
@@ -1136,6 +1231,193 @@ wxPanel* wxMaximaFrame::CreateStatPane()
   return panel;
 }
 
+void wxMaximaFrame::CharacterButtonPressed(wxMouseEvent &event)
+{
+  wxChar ch = event.GetId();
+  wxString ch_string(ch);
+  m_console->InsertText(ch_string);
+}
+
+wxPanel *wxMaximaFrame::CharButton(wxPanel *parent,wxChar ch,wxString description,bool matchesMaximaCommand)
+{
+  wxPanel *panel = new wxPanel(parent,ch);
+  wxBoxSizer *vbox = new wxBoxSizer(wxVERTICAL);
+  wxStaticText *text = new wxStaticText(panel,ch,wxString(ch));
+  vbox->Add(text,1,wxALL | wxCENTER,0);
+  
+  if(description.Length()>0)
+    text->SetToolTip(description);
+  text->Connect(wxEVT_LEFT_UP,wxMouseEventHandler(wxMaximaFrame::CharacterButtonPressed),NULL,this);
+  panel->Connect(wxEVT_LEFT_UP,wxMouseEventHandler(wxMaximaFrame::CharacterButtonPressed),NULL,this);
+  panel->SetSizerAndFit(vbox);
+  return panel;
+}
+
+#ifdef wxUSE_UNICODE
+wxPanel* wxMaximaFrame::CreateGreekPane()
+{
+  wxPanel *panel = new wxPanel(this, -1);
+  wxBoxSizer *vbox = new wxBoxSizer(wxVERTICAL);
+
+  int style = wxALL | wxEXPAND;
+#if defined __WXMSW__
+  int border = 1;
+#else
+  int border = 0;
+#endif
+
+  wxFlexGridSizer *lowercase = new wxFlexGridSizer(8);
+  lowercase->SetFlexibleDirection(wxBOTH);
+  for (int i=0;i<8;i++)
+    lowercase->AddGrowableCol(i,1);
+  lowercase->Add(CharButton(panel,  wxT('\x03B1'),_("alpha")),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x03B2'),_("beta")),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x03B3'),_("gamma")),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x03B4'),_("delta")),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x03B5'),_("epsilon")),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x03B6'),_("zeta")),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x03B7'),_("eta")),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x03B8'),_("theta")),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x03B9'),_("iota")),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x03BA'),_("kappa")),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x03BB'),_("lambda")),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x03BC'),_("my")),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x03BD'),_("ny")),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x03BE'),_("xi")),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x03BF'),_("omnikron")),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x03C0'),_("pi")),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x03C1'),_("rho")),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x03C3'),_("sigma")),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x03C4'),_("tau")),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x03C5'),_("ypsilon")),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x03C6'),_("phi")),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x03C7'),_("chi")),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x03C8'),_("psi")),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x03C9'),_("omega")),0,wxALL | wxEXPAND,2);
+  vbox->Add(lowercase,0,style,border);
+
+  wxFlexGridSizer *uppercase = new wxFlexGridSizer(8);
+  uppercase->SetFlexibleDirection(wxBOTH);
+  for (int i=0;i<8;i++)
+    uppercase->AddGrowableCol(i,1);
+
+  uppercase->Add(CharButton(panel,  wxT('\x0391'),_("Alpha")),0,wxALL | wxEXPAND,2);
+  uppercase->Add(CharButton(panel,  wxT('\x0392'),_("Beta")),0,wxALL | wxEXPAND,2);
+  uppercase->Add(CharButton(panel,  wxT('\x0393'),_("Gamma")),0,wxALL | wxEXPAND,2);
+  uppercase->Add(CharButton(panel,  wxT('\x0394'),_("Delta")),0,wxALL | wxEXPAND,2);
+  uppercase->Add(CharButton(panel,  wxT('\x0395'),_("Epsilon")),0,wxALL | wxEXPAND,2);
+  uppercase->Add(CharButton(panel,  wxT('\x0396'),_("Zeta")),0,wxALL | wxEXPAND,2);
+  uppercase->Add(CharButton(panel,  wxT('\x0397'),_("Eta")),0,wxALL | wxEXPAND,2);
+  uppercase->Add(CharButton(panel,  wxT('\x0398'),_("Theta")),0,wxALL | wxEXPAND,2);
+  uppercase->Add(CharButton(panel,  wxT('\x0399'),_("Iota")),0,wxALL | wxEXPAND,2);
+  uppercase->Add(CharButton(panel,  wxT('\x039A'),_("Kappa")),0,wxALL | wxEXPAND,2);
+  uppercase->Add(CharButton(panel,  wxT('\x039B'),_("Lambda")),0,wxALL | wxEXPAND,2);
+  uppercase->Add(CharButton(panel,  wxT('\x039C'),_("My")),0,wxALL | wxEXPAND,2);
+  uppercase->Add(CharButton(panel,  wxT('\x039D'),_("Ny")),0,wxALL | wxEXPAND,2);
+  uppercase->Add(CharButton(panel,  wxT('\x039E'),_("Xi")),0,wxALL | wxEXPAND,2);
+  uppercase->Add(CharButton(panel,  wxT('\x039F'),_("Omnikron")),0,wxALL | wxEXPAND,2);
+  uppercase->Add(CharButton(panel,  wxT('\x03A0'),_("Pi")),0,wxALL | wxEXPAND,2);
+  uppercase->Add(CharButton(panel,  wxT('\x03A1'),_("Rho")),0,wxALL | wxEXPAND,2);
+  uppercase->Add(CharButton(panel,  wxT('\x03A3'),_("Sigma")),0,wxALL | wxEXPAND,2);
+  uppercase->Add(CharButton(panel,  wxT('\x03A4'),_("Tau")),0,wxALL | wxEXPAND,2);
+  uppercase->Add(CharButton(panel,  wxT('\x03A5'),_("Ypsilon")),0,wxALL | wxEXPAND,2);
+  uppercase->Add(CharButton(panel,  wxT('\x03A6'),_("Phi")),0,wxALL | wxEXPAND,2);
+  uppercase->Add(CharButton(panel,  wxT('\x03A7'),_("Chi")),0,wxALL | wxEXPAND,2);
+  uppercase->Add(CharButton(panel,  wxT('\x03A8'),_("Psi")),0,wxALL | wxEXPAND,2);
+  uppercase->Add(CharButton(panel,  wxT('\x03A9'),_("Omega")),0,wxALL | wxEXPAND,2);
+  vbox->Add(uppercase,0,style,border);
+
+
+  panel->SetSizerAndFit(vbox);
+  vbox->SetSizeHints(panel);
+
+  return panel;
+}
+
+wxPanel* wxMaximaFrame::CreateSymbolsPane()
+{
+  wxPanel *panel = new wxPanel(this, -1);
+  wxBoxSizer *vbox = new wxBoxSizer(wxVERTICAL);
+
+  int style = wxALL | wxEXPAND;
+#if defined __WXMSW__
+  int border = 1;
+#else
+  int border = 0;
+#endif
+
+  wxFlexGridSizer *lowercase = new wxFlexGridSizer(8);
+  lowercase->SetFlexibleDirection(wxBOTH);
+  for (int i=0;i<8;i++)
+    lowercase->AddGrowableCol(i,1);
+  lowercase->Add(CharButton(panel,  wxT('\x00BD'),_("1/2"),true),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x00B2'),_("to the power of 2"),true),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x00B3'),_("to the power of 3"),true),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x221A'),_("sqrt (needs parenthesis for its argument to work as a maxima command)"),true),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x2148')),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x2147')),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x210F')),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x2208'),_("in")),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x2203'),_("exists")),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x2204'),_("there is no")),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x21D2'),_("\"implies\" symbol"),true),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x221E'),_("Infinity"),true),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x2205'),_("empty")),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x25b6')),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x25b8')),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x22C0'),_("and"),true),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x22C1'),_("or"),true),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x22BB'),_("xor"),true),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x22BC'),_("nand"),true),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x22BD'),_("nor"),true),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x21D4'),_("equivalent"),true),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x00b1'),_("plus or minus")),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x00AC'),_("not"),true),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x22C3'),_("union")),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x22C2'),_("intersection")),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x2286'),_("subset or equal")),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x2282'),_("subset")),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x2288'),_("not subset or equal")),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x2284'),_("not subset")),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x0127')),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x0126')),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x2202'),_("partial sign")),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x222b'),_("Integral sign")),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x2245')),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x221d'),_("proportional to")),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x2260'),_("not bytewise identical"),true),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x2264'),_("less or equal"),true),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x2265'),_("greater than or equal"),true),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x226A'),_("much less than")),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x226B'),_("much greater than")),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x2263'),_("Identical to")),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x2211'),_("Sum sign")),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x220F'),_("Product sign")),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x2225'),_("Parallel to")),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x27C2'),_("Perpendicular to")),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x219D'),_("Leads to")),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x2192'),_("Right arrow")),0,wxALL | wxEXPAND,2);
+  lowercase->Add(CharButton(panel,  wxT('\x220e'),_("End of proof")),0,wxALL | wxEXPAND,2);
+  vbox->Add(lowercase,0,style,border);
+
+  wxGridSizer *uppercase = new wxGridSizer(8);
+/*  uppercase->SetFlexibleDirection(wxBOTH);
+  for (int i=0;i<8;i++)
+    uppercase->AddGrowableCol(i,1);
+*/
+  wxString symbolPaneAdditionalChars=wxT("üØ");
+  wxConfig::Get()->Read(wxT("symbolPaneAdditionalChars"),&symbolPaneAdditionalChars);
+  for (size_t i=0;i<symbolPaneAdditionalChars.Length();i++)
+  uppercase->Add(CharButton(panel, symbolPaneAdditionalChars[i],_("A symbol from the configuraton dialogue")),0,wxALL | wxEXPAND,2);
+  vbox->Add(uppercase,0,style,border);
+
+  panel->SetSizerAndFit(vbox);
+  vbox->SetSizeHints(panel);
+
+  return panel;
+}
+#endif
+
 wxPanel *wxMaximaFrame::CreateFormatPane()
 {
   wxGridSizer *grid = new wxGridSizer(2);
